# BalderHub Package ``balderhub-ant``

This is a BalderHub package for the [Balder](https://docs.balder.dev) test framework. If you are new to Balder check out the
[official documentation](https://docs.balder.dev) first.

.. note::
    This package is for development only. This is not a substitute for the official specification and it isn't intended
    to use this package as reference. Have a look at the thisisant.com documentation for more details.

## Installation

You can install the latest release with pip:

```
python -m pip install balderhub-ant
```

# Check out the documentation

If you need more information, 
[checkout the ``balderhub-ant`` documentation](https://hub.balder.dev/projects/ant).


# License

This BalderHub package is free and Open-Source

Copyright (c)  2026 Max Stahlschmidt

Distributed under the terms of the MIT license